Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(54)

Unified Diff: client/tools/buildbot_annotated_steps.py

Issue 16923004: Remove AWS_CREDENTIAL_FILE env-variable for editor bots as well (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: client/tools/buildbot_annotated_steps.py
diff --git a/client/tools/buildbot_annotated_steps.py b/client/tools/buildbot_annotated_steps.py
index 0eba6d52b6c9d7b431680ef48c717311ccbaa0ab..c7360e9c7354ccd923368e98e5cdae4bc67490f2 100755
--- a/client/tools/buildbot_annotated_steps.py
+++ b/client/tools/buildbot_annotated_steps.py
@@ -105,10 +105,12 @@ def ProcessTools(mode, name, version):
'--mode=' + mode, '--revision=' + version,
'--name=' + name, '--out=' + outdir]
local_env = os.environ.copy()
# The buildbot sets BOTO_CONFIG to the chromium specific file, we use the one
# in home.
if 'BOTO_CONFIG' in local_env:
del local_env['BOTO_CONFIG']
+ if 'AWS_CREDENTIAL_FILE' in local_env:
+ del local_env['AWS_CREDENTIAL_FILE']
#if 'linux' in name:
# javahome = os.path.join(os.path.expanduser('~'), 'jdk1.6.0_25')
# local_env['JAVA_HOME'] = javahome
@@ -105,10 +105,12 @@ def ProcessTools(mode, name, version):
'--name=' + name, '--out=' + outdir]
local_env = os.environ.copy()
- # The buildbot sets BOTO_CONFIG to the chromium specific file, we use the one
- # in home.
+ # The buildbot sets AWS_CREDENTIAL_FILE/BOTO_CONFIG to the chromium specific
+ # file, we use the one in home.
if 'BOTO_CONFIG' in local_env:
del local_env['BOTO_CONFIG']
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698